@@ -1,4 +1,6 @@
 import inspect
+from mftoolbox.constants import Color as c
+
 def error_stack(error, message):
     """
     Imprime mensagem de erro criada pelo usuário
@@ -12,7 +14,7 @@ def error_stack(error, message):
     """
     context = inspect.getframeinfo(inspect.currentframe(), context=1), inspect.getouterframes(inspect.currentframe(),context=1)
     error = "Erro: " + error
-    print(Color.dark_red_background + Color.bold + Color.white + error + " " * (60 - len(error)) + Color.end)
+    print(c.dark_red_background + c.bold + c.white + error + " " * (60 - len(error)) + c.end)
     print(message)
     print('Lista de chamadas:')
     last = False
